From 5c0eee79183890c3243a80424626ad00e223870b Mon Sep 17 00:00:00 2001
From: John Alway <thaleslv@yahoo.com>
Date: Sat, 23 Nov 2019 14:12:05 -0600
Subject: [PATCH] comctl32/tests: Fix combobox height after SetItemHeight,
 SetWindowPos.

This bug happens when the message CB_SETITEMHEIGHT is followed by
SetWindowPos() for a combobox. This patch applies to the window
class "ComboBox" and not to "ComboBoxEx32".

Wine-Bug: https://bugs.winehq.org/show_bug.cgi?id=47489
Signed-off-by: John Alway <thaleslv@yahoo.com>
---
 dlls/comctl32/tests/combo.c | 36 ++++++++++++++++++++++++++++++++++++
 1 file changed, 36 insertions(+)

diff --git a/dlls/comctl32/tests/combo.c b/dlls/comctl32/tests/combo.c
index 4757fa3..8ac23f5 100644
--- a/dlls/comctl32/tests/combo.c
+++ b/dlls/comctl32/tests/combo.c
@@ -1348,6 +1348,41 @@ static void test_combo_ctlcolor(void)
     DestroyWindow(combo);
 }
 
+static void test_combo_height_reset(void)
+{
+    HWND hCombo;
+    HFONT hFont;
+    int height;
+    
+    /* This test requires the WC_COMBOBOXA style.  It won't work for WC_COMBOBOXEXA */
+    hCombo = CreateWindowExA(0, WC_COMBOBOXA, NULL, WS_BORDER | WS_VISIBLE | WS_CHILD | CBS_DROPDOWN, 0, 0, 300, 300,
+                                hComboExParentWnd, NULL, hMainHinst, NULL);
+
+    /* Add items to the combobox */
+    SendMessageA(hCombo, (UINT)CB_ADDSTRING, (WPARAM)0, (LPARAM)"Item 0");
+    SendMessageA(hCombo, (UINT)CB_ADDSTRING, (WPARAM)0, (LPARAM)"Item 1");
+    SendMessageA(hCombo, (UINT)CB_ADDSTRING, (WPARAM)0, (LPARAM)"Item 2");
+    SendMessageA(hCombo, (UINT)CB_ADDSTRING, (WPARAM)0, (LPARAM)"Item 3");
+    SendMessageA(hCombo, CB_SETCURSEL, 1, 0);
+
+    /* Create large enough font for test to work. */
+    hFont = CreateFontA(17, 0, 0, 0, FW_DONTCARE, FALSE, FALSE, FALSE, ANSI_CHARSET, OUT_DEFAULT_PRECIS,
+                        CLIP_DEFAULT_PRECIS, DEFAULT_QUALITY, DEFAULT_PITCH|FF_DONTCARE, "Marlett");
+    SendMessageA(hCombo, WM_SETFONT, (WPARAM)hFont, FALSE);
+
+    /* Set Item Height followed by SetWindowPos() is the test */
+    SendMessageA(hCombo, CB_SETITEMHEIGHT, -1, 4);
+
+    /* SetWindowPos() should set the height according to font size*/
+    SetWindowPos(hCombo,NULL, 10,10,150,20, SWP_SHOWWINDOW);
+    height = SendMessageA(hCombo, CB_GETITEMHEIGHT, -1, 0);
+    ok(height > 6, "SetWindowPos() failed. Height (%d)\n", height);
+
+    /* Cleanup */
+    DestroyWindow(hCombo);
+    DeleteObject(hFont);
+}
+
 START_TEST(combo)
 {
     ULONG_PTR ctx_cookie;
@@ -1392,6 +1427,7 @@ START_TEST(combo)
     test_combo_dropdown_size(0);
     test_combo_dropdown_size(CBS_NOINTEGRALHEIGHT);
     test_combo_ctlcolor();
+    test_combo_height_reset();
 
     cleanup();
     unload_v6_module(ctx_cookie, hCtx);
-- 
2.7.4

